@@ -438,8 +438,10 @@ clearlooks_draw_entry (cairo_t *cr,
 	/* Draw the inner shadow */
 	if (params->focus)
 	{
-		/* XXX Fix this with focus->has_color */
-		ge_cairo_set_color (cr, &colors->spot[0]);
+		CairoColor focus_shadow;
+		ge_shade_color (&border, 1.61, &focus_shadow);
+		
+		clearlooks_set_mixed_color (cr, base, &focus_shadow, 0.5);
 		ge_cairo_inner_rounded_rectangle (cr, 2, 2, width-4, height-4, MAX(0, radius-1), params->corners);
 		cairo_stroke (cr);
 	}
@@ -1741,6 +1743,16 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			x -= 1;
+			width += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			width += 1;
+		}
 	}
 	else
 	{
@@ -1748,6 +1760,16 @@ clearlooks_draw_scrollbar_stepper (cairo_t *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			y -= 1;
+			height += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			height += 1;
+		}
 	}
 
 	cairo_translate (cr, x, y);
@@ -2453,6 +2475,18 @@ clearlooks_draw_focus (cairo_t *cr,
 	cairo_stroke (cr);
 }
 
+void
+clearlooks_set_mixed_color (cairo_t          *cr,
+                            const CairoColor *color1,
+                            const CairoColor *color2,
+                            gdouble mix_factor)
+{
+	CairoColor composite;
+
+	ge_mix_color (color1, color2, mix_factor, &composite);
+	ge_cairo_set_color (cr, &composite);
+}
+
 void
 clearlooks_register_style_classic (ClearlooksStyleFunctions *functions, ClearlooksStyleConstants *constants)
 {
