@@ -1,28 +1,33 @@
-/* Clearlooks Glossy style
- * Copyright (C) 2006 Benjamin Berg
- * Copyright (C) 2007 Andrea Cimitan
+/* Clearlooks - a cairo based GTK+ engine
+ * Copyright (C) 2006 Benjamin Berg <benjamin@sipsolutions.net>
+ * Copyright (C) 2007-2008 Andrea Cimitan <andrea.cimitan@gmail.com>
  *
  * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
+ * modify it under the terms of the GNU Lesser General Public
  * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
+ * version 2.1 of the License, or (at your option) any later version.
+ * 
  * This library is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
+ * Lesser General Public License for more details.
+ * 
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Project contact: <gnome-themes-list@gnome.org>
  *
+ *
+ * This file defines the Clearlooks Glossy style
  * Written by Andrea Cimitan <andrea.cimitan@gmail.com>
  *        and Benjamin Berg <benjamin@sipsolutions.net>
  * Based on code by Richard Stellingwerff <remenic@gmail.com>
  *              and Daniel Borgmann <daniel.borgmann@gmail.com>
  * from the ubuntulooks engine.
+ *
  */
+ 
 
 #include "clearlooks_draw.h"
 #include "clearlooks_style.h"
@@ -61,18 +66,6 @@ clearlooks_draw_glossy_gradient (cairo_t         *cr,
 	cairo_pattern_destroy (pt);
 }
 
-static void
-clearlooks_set_mixed_color (cairo_t          *cr, 
-                            const CairoColor *color1, 
-                            const CairoColor *color2, 
-                            gdouble mix_factor)
-{
-	CairoColor composite;
-
-	ge_mix_color (color1, color2, mix_factor, &composite);
-	ge_cairo_set_color (cr, &composite);
-}
-
 /* This draw_inset implementation only differes in the shades values from the
  * default one. */
 static void
@@ -939,6 +932,16 @@ clearlooks_glossy_draw_scrollbar_stepper (cairo_t *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_TOPRIGHT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			x -= 1;
+			width += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			width += 1;
+		}
 	}
 	else
 	{
@@ -946,6 +949,16 @@ clearlooks_glossy_draw_scrollbar_stepper (cairo_t *cr,
 			corners = CR_CORNER_TOPLEFT | CR_CORNER_TOPRIGHT;
 		else if (stepper->stepper == CL_STEPPER_D)
 			corners = CR_CORNER_BOTTOMLEFT | CR_CORNER_BOTTOMRIGHT;
+
+		if (stepper->stepper == CL_STEPPER_B)
+		{
+			y -= 1;
+			height += 1;
+		}
+		else if (stepper->stepper == CL_STEPPER_C)
+		{
+			height += 1;
+		}
 	}
 	
 	cairo_translate (cr, x, y);
